#' @name ows4R
#' @aliases ows4R-package
#' @aliases ows4R
#' 
#' @title Interface to OGC Web-Services
#' @description Provides an Interface to Web-Services defined as standards by the Open Geospatial Consortium (OGC), including Web Feature Service
#' (WFS) for vector data, Web Coverage Service (WCS), Catalogue Service (CSW) for ISO/OGC metadata, and associated standards such as the common 
#' web-service specification (OWS) and OGC Filter Encoding. Partial support is provided for the Web Map Service (WMS) and Web Processing Service (WPS). 
#' The purpose is to add support for additional OGC service standards such as Web Coverage Processing Service (WCPS) or OGC API.
#'  
#'@author Emmanuel Blondel \email{emmanuel.blondel1@@gmail.com}
#'
"_PACKAGE"